@@ -1,12 +1,14 @@
 from version import ELECTRUM_VERSION
 from util import format_satoshis, print_msg, print_error, set_verbosity
-from wallet import Synchronizer, WalletStorage, Wallet, Imported_Wallet
+from wallet import Synchronizer, Wallet, Imported_Wallet
+from storage import WalletStorage
 from coinchooser import COIN_CHOOSERS
 from network import Network, pick_random_server
 from interface import Connection, Interface
 from simple_config import SimpleConfig, get_config, set_config
 import bitcoin
 import transaction
+import daemon
 from transaction import Transaction
 from plugins import BasePlugin
 from commands import Commands, known_commands
