@@ -45,22 +45,32 @@ from version import ELECTRUM_VERSION, PROTOCOL_VERSION
 
 DEFAULT_PORTS = {'t':'50001', 's':'50002'}
 
+#There is a schedule to move the default list to e-x (electrumx) by Jan 2018
+#Schedule is as follows:
+#move ~3/4 to e-x by 1.4.17
+#then gradually switch remaining nodes to e-x nodes
+
 DEFAULT_SERVERS = {
-    'erbium1.sytes.net':{'t':'50001', 's':'50002'},
-    'ecdsa.net':{'t':'50001', 's':'110'},
-    'gh05.geekhosters.com':{'t':'50001', 's':'50002'},
-    'VPS.hsmiths.com':{'t':'50001', 's':'50002'},
-    'electrum.anduck.net':{'t':'50001', 's':'50002'},
-    'electrum.no-ip.org':{'t':'50001', 's':'50002'},
-    'us.electrum.be':DEFAULT_PORTS,
-    'electrum.villocq.com':{'t':'50001', 's':'50002'},
-    'us10.einfachmalnettsein.de':{'t':'50001', 's':'50002'},
-    'electrum.trouth.net':{'t':'50001', 's':'50002'},
-    'Electrum.hsmiths.com':{'t':'8080', 's':'995'},
-    'electrum3.hachre.de':{'t':'50001', 's':'50002'},
-    'elec.luggs.co':{'t':'80', 's':'443'},
-    'btc.smsys.me':{'t':'110', 's':'995'},
-    'btc.mustyoshi.com':{'t':'50001', 's':'50002'},
+    'erbium1.sytes.net':DEFAULT_PORTS,                  # core, e-x
+    'ecdsa.net':{'t':'50001', 's':'110'},               # core, e-x
+    'gh05.geekhosters.com':DEFAULT_PORTS,               # core, e-s
+    'VPS.hsmiths.com':DEFAULT_PORTS,                    # core, e-x
+    'electrum.anduck.net':DEFAULT_PORTS,                # core, e-s; banner with version pending
+    'electrum.no-ip.org':DEFAULT_PORTS,                 # core, e-s
+    'electrum.be':DEFAULT_PORTS,                        # core, e-x
+    'helicarrier.bauerj.eu':DEFAULT_PORTS,              # core, e-x
+    'elex01.blackpole.online':DEFAULT_PORTS,            # core, e-x
+    'electrumx.not.fyi':DEFAULT_PORTS,                  # core, e-x
+    'node.xbt.eu':DEFAULT_PORTS,                        # core, e-x
+    'kirsche.emzy.de':DEFAULT_PORTS,                    # core, e-x
+    'electrum.villocq.com':DEFAULT_PORTS,               # core?, e-s; banner with version recommended
+    'us11.einfachmalnettsein.de':DEFAULT_PORTS,         # core, e-x
+    'electrum.trouth.net':DEFAULT_PORTS,                # BU, e-s
+    'Electrum.hsmiths.com':{'t':'8080', 's':'995'},     # core, e-x
+    'electrum3.hachre.de':DEFAULT_PORTS,                # core, e-x
+    'b.1209k.com':DEFAULT_PORTS,                        # XT, jelectrum
+    'elec.luggs.co':{ 's':'443'},                       # core, e-x
+    'btc.smsys.me':{'t':'110', 's':'995'},              # BU, e-x
 }
 
 def set_testnet():
@@ -548,10 +558,11 @@ class Network(util.DaemonThread):
             if error is None:
                 self.donation_address = result
         elif method == 'blockchain.estimatefee':
-            if error is None:
+            if error is None and result > 0:
                 i = params[0]
-                self.config.fee_estimates[i] = int(result * COIN)
-                self.print_error("fee_estimates[%d]" % i, self.config.fee_estimates[i])
+                fee = int(result*COIN)
+                self.config.fee_estimates[i] = fee
+                self.print_error("fee_estimates[%d]" % i, fee)
                 self.notify('fee')
         elif method == 'blockchain.relayfee':
             if error is None:
