@@ -22,6 +22,7 @@
 # ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 # CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
+import socket
 
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
@@ -38,7 +39,7 @@ protocol_letters = 'ts'
 class NetworkDialog(WindowModalDialog):
     def __init__(self, network, config, parent):
         WindowModalDialog.__init__(self, parent, _('Network'))
-        self.setMinimumSize(375, 20)
+        self.setMinimumSize(400, 20)
         self.nlayout = NetworkChoiceLayout(network, config)
         vbox = QVBoxLayout(self)
         vbox.addLayout(self.nlayout.layout())
@@ -56,6 +57,7 @@ class NetworkChoiceLayout(object):
         self.network = network
         self.config = config
         self.protocol = None
+        self.tor_proxy = None
 
         self.servers = network.get_servers()
         host, port, protocol, proxy_config, auto_connect = network.get_parameters()
@@ -108,7 +110,7 @@ class NetworkChoiceLayout(object):
         # use SSL
         self.ssl_cb = QCheckBox(_('Use SSL'))
         self.ssl_cb.setChecked(auto_connect)
-        grid.addWidget(self.ssl_cb, 3, 1, 1, 3)
+        grid.addWidget(self.ssl_cb, 0, 2, 1, 1, Qt.AlignRight)
         self.ssl_cb.stateChanged.connect(self.change_protocol)
 
         # auto connect
@@ -153,29 +155,50 @@ class NetworkChoiceLayout(object):
         self.proxy_port = QLineEdit()
         self.proxy_port.setFixedWidth(60)
         self.proxy_mode.addItems(['NONE', 'SOCKS4', 'SOCKS5', 'HTTP'])
+        self.proxy_user = QLineEdit()
+        self.proxy_user.setPlaceholderText(_("Proxy user"))
+        self.proxy_password = QLineEdit()
+        self.proxy_password.setPlaceholderText(_("Password"))
+        self.proxy_password.setEchoMode(QLineEdit.Password)
+        self.proxy_password.setFixedWidth(60)
 
         def check_for_disable(index = False):
             if self.config.is_modifiable('proxy'):
-                if self.proxy_mode.currentText() != 'NONE':
-                    self.proxy_host.setEnabled(True)
-                    self.proxy_port.setEnabled(True)
-                else:
-                    self.proxy_host.setEnabled(False)
-                    self.proxy_port.setEnabled(False)
+                for w in [self.proxy_host, self.proxy_port, self.proxy_user, self.proxy_password]:
+                    w.setEnabled(self.proxy_mode.currentText() != 'NONE')
             else:
                 for w in [self.proxy_host, self.proxy_port, self.proxy_mode]: w.setEnabled(False)
 
         check_for_disable()
         self.proxy_mode.connect(self.proxy_mode, SIGNAL('currentIndexChanged(int)'), check_for_disable)
+
         self.proxy_mode.setCurrentIndex(self.proxy_mode.findText(str(proxy_config.get("mode").upper())))
         self.proxy_host.setText(proxy_config.get("host"))
         self.proxy_port.setText(proxy_config.get("port"))
+        self.proxy_user.setText(proxy_config.get("user", ""))
+        self.proxy_password.setText(proxy_config.get("password", ""))
+
+        self.proxy_mode.connect(self.proxy_mode, SIGNAL('currentIndexChanged(int)'), self.proxy_settings_changed)
+        self.proxy_host.connect(self.proxy_host, SIGNAL('textEdited(QString)'), self.proxy_settings_changed)
+        self.proxy_port.connect(self.proxy_port, SIGNAL('textEdited(QString)'), self.proxy_settings_changed)
+        self.proxy_user.connect(self.proxy_user, SIGNAL('textEdited(QString)'), self.proxy_settings_changed)
+        self.proxy_password.connect(self.proxy_password, SIGNAL('textEdited(QString)'), self.proxy_settings_changed)
 
         grid.addWidget(QLabel(_('Proxy') + ':'), 4, 0)
         grid.addWidget(self.proxy_mode, 4, 1)
         grid.addWidget(self.proxy_host, 4, 2)
         grid.addWidget(self.proxy_port, 4, 3)
+        grid.addWidget(self.proxy_user, 5, 2)
+        grid.addWidget(self.proxy_password, 5, 3)
+        self.tor_button = QCheckBox(_("Use Tor Proxy"))
+        self.tor_button.setIcon(QIcon(":icons/tor_logo.png"))
+        self.tor_button.hide()
+        self.tor_button.clicked.connect(self.use_tor_proxy)
+        grid.addWidget(self.tor_button, 6, 2, 1, 2)
         self.layout_ = vbox
+        self.td = td = TorDetector()
+        td.found_proxy.connect(self.suggest_proxy)
+        td.start()
 
     def layout(self):
         return self.layout_
@@ -243,10 +266,66 @@ class NetworkChoiceLayout(object):
         if self.proxy_mode.currentText() != 'NONE':
             proxy = { 'mode':str(self.proxy_mode.currentText()).lower(),
                       'host':str(self.proxy_host.text()),
-                      'port':str(self.proxy_port.text()) }
+                      'port':str(self.proxy_port.text()),
+                      'user':str(self.proxy_user.text()),
+                      'password':str(self.proxy_password.text())}
         else:
             proxy = None
 
         auto_connect = self.autoconnect_cb.isChecked()
 
         self.network.set_parameters(host, port, protocol, proxy, auto_connect)
+
+    def suggest_proxy(self, found_proxy):
+        self.tor_proxy = found_proxy
+        self.tor_button.setText("Use Tor proxy at port " + str(found_proxy[1]))
+        if self.proxy_mode.currentIndex() == 2 \
+            and self.proxy_host.text() == "127.0.0.1" \
+                and self.proxy_port.text() == str(found_proxy[1]):
+            self.tor_button.setChecked(True)
+        self.tor_button.show()
+
+    def use_tor_proxy(self, use_it):
+        # 2 = SOCKS5
+        if not use_it:
+            self.proxy_mode.setCurrentIndex(0)
+            self.tor_button.setChecked(False)
+        else:
+            self.proxy_mode.setCurrentIndex(2)
+            self.proxy_host.setText("127.0.0.1")
+            self.proxy_port.setText(str(self.tor_proxy[1]))
+            self.proxy_user.setText("")
+            self.proxy_password.setText("")
+            self.tor_button.setChecked(True)
+
+    def proxy_settings_changed(self):
+        self.tor_button.setChecked(False)
+
+
+class TorDetector(QThread):
+    found_proxy = pyqtSignal(object)
+
+    def __init__(self):
+        QThread.__init__(self)
+
+    def run(self):
+        # Probable ports for Tor to listen at
+        ports = [9050, 9150]
+        for p in ports:
+            if TorDetector.is_tor_port(p):
+                self.found_proxy.emit(("127.0.0.1", p))
+                return
+
+    @staticmethod
+    def is_tor_port(port):
+        try:
+            s = socket._socketobject(socket.AF_INET, socket.SOCK_STREAM)
+            s.settimeout(0.1)
+            s.connect(("127.0.0.1", port))
+            # Tor responds uniquely to HTTP-like requests
+            s.send("GET\n")
+            if "Tor is not an HTTP Proxy" in s.recv(1024):
+                return True
+        except socket.error:
+            pass
+        return False
