@@ -29,9 +29,10 @@ from electrum.bitcoin import is_address
 
 
 class UTXOList(MyTreeWidget):
+    filter_columns = [0, 2]  # Address, Label
 
     def __init__(self, parent=None):
-        MyTreeWidget.__init__(self, parent, self.create_menu, [ _('Address'), _('Label'), _('Amount'), ''], 1)
+        MyTreeWidget.__init__(self, parent, self.create_menu, [ _('Address'), _('Output point'), _('Label'), _('Amount'), ''], 2)
         self.setSelectionMode(QAbstractItemView.ExtendedSelection)
 
     def get_name(self, x):
@@ -42,44 +43,24 @@ class UTXOList(MyTreeWidget):
         item = self.currentItem()
         self.clear()
         self.utxos = self.wallet.get_utxos()
-        address_items = {}
         for x in self.utxos:
             address = x.get('address')
-            address_item = address_items.get(address)
-            if address_item is None:
-                label = self.wallet.get_label(address)
-                address_item = QTreeWidgetItem([address, label, ''])
-                address_item.setData(0, Qt.UserRole, address)
-                address_items[address] = address_item
-                self.addChild(address_item)
-                address_item.setExpanded(True)
-                if self.wallet.is_frozen(address):
-                    address_item.setBackgroundColor(0, QColor('lightblue'))
-
             name = self.get_name(x)
             label = self.wallet.get_label(x.get('prevout_hash'))
             amount = self.parent.format_amount(x['value'])
-            utxo_item = QTreeWidgetItem([name[0:20]+'...'+name[-20:], label, amount])
+            utxo_item = QTreeWidgetItem([address, name[0:10] + '...' + name[-2:], label, amount])
             utxo_item.setFont(0, QFont(MONOSPACE_FONT))
             utxo_item.setFont(1, QFont(MONOSPACE_FONT))
             utxo_item.setData(0, Qt.UserRole, name)
-            address_item.addChild(utxo_item)
+            if self.wallet.is_frozen(address):
+                utxo_item.setBackgroundColor(0, QColor('lightblue'))
+            self.addChild(utxo_item)
 
     def create_menu(self, position):
         selected = [str(x.data(0, Qt.UserRole).toString()) for x in self.selectedItems()]
         if not selected:
             return
         menu = QMenu()
-        if len(selected) == 1 and is_address(selected[0]):
-            addr = selected[0]
-            coins = filter(lambda x: x.get('address') == addr, self.utxos)
-            menu.addAction(_("Copy Address"), lambda: self.parent.app.clipboard().setText(addr))
-            if not self.wallet.is_frozen(addr):
-                menu.addAction(_("Freeze"), lambda: self.parent.set_frozen_state([addr], True))
-            else:
-                menu.addAction(_("Unfreeze"), lambda: self.parent.set_frozen_state([addr], False))
-            menu.addAction(_("Spend from Address"), lambda: self.parent.spend_coins(coins))
-        else:
-            coins = filter(lambda x: self.get_name(x) in selected, self.utxos)
-            menu.addAction(_("Spend"), lambda: self.parent.spend_coins(coins))
+        coins = filter(lambda x: self.get_name(x) in selected, self.utxos)
+        menu.addAction(_("Spend"), lambda: self.parent.spend_coins(coins))
         menu.exec_(self.viewport().mapToGlobal(position))
