@@ -10,5 +10,5 @@ class Plugin(LabelsPlugin):
 
     def on_pulled(self, wallet):
         self.print_error('on pulled')
-        self.window.update_history_tab()
+        self.window._trigger_update_history()
 
